#
# Lockstep Platform SDK for Python
#
# (c) 2021-2023 Lockstep, Inc.
#
# For the full copyright and license information, please view the LICENSE
# file that was distributed with this source code.
#
# @author     Lockstep Network <support@lockstep.io>
# @copyright  2021-2023 Lockstep, Inc.
# @link       https://github.com/Lockstep-Network/lockstep-sdk-python
#


from dataclasses import dataclass

@dataclass
class PaymentModel:
    """
    A Payment represents money sent from one company to another. A
    single payment may contain payments for one or more invoices; it is
    also possible for payments to be made in advance of an invoice, for
    example, as a deposit. The creator of the Payment is identified by
    the `CustomerId` field, and the recipient of the Payment is
    identified by the `CompanyId` field. Most Payments are uniquely
    identified both by a Lockstep Platform ID number and a customer ERP
    "key" that was generated by the system that originated the Payment.
    Payments that have not been fully applied have a nonzero
    `UnappliedAmount` value, which represents a deposit that has been
    paid and not yet applied to an Invoice.
    """

    groupKey: object | None = None
    paymentId: object | None = None
    companyId: object | None = None
    erpKey: object | None = None
    erpWriteStatus: object | None = None
    erpWriteStatusName: object | None = None
    paymentType: object | None = None
    tenderType: object | None = None
    isOpen: object | None = None
    memoText: object | None = None
    paymentDate: object | None = None
    postDate: object | None = None
    paymentAmount: object | None = None
    unappliedAmount: object | None = None
    currencyCode: object | None = None
    bankAccountId: object | None = None
    referenceCode: object | None = None
    created: object | None = None
    createdUserId: object | None = None
    modified: object | None = None
    modifiedUserId: object | None = None
    appEnrollmentId: object | None = None
    isVoided: object | None = None
    inDispute: object | None = None
    currencyRate: object | None = None
    baseCurrencyPaymentAmount: object | None = None
    baseCurrencyUnappliedAmount: object | None = None
    serviceFabricStatus: object | None = None
    sourceModifiedDate: object | None = None
    applications: list[object] | None = None
    notes: list[object] | None = None
    attachments: list[object] | None = None
    customFieldDefinitions: list[object] | None = None
    customFieldValues: list[object] | None = None

    def to_dict(self) -> dict:
        return dataclass.asdict(self)
